==> acquia_contenthub-3.0.1.tar.gz: acquia_contenthub/tests/modules/acquia_contenthub_server_test/src/Client/ClientFactoryMock.php <==
<?php

namespace Drupal\acquia_contenthub_server_test\Client;

use Acquia\ContentHubClient\ContentHubClient;
use Acquia\ContentHubClient\Settings;
use Drupal\acquia_contenthub\Client\ClientFactory;
use Drupal\acquia_contenthub\Exception\PlatformIncompatibilityException;
use Drupal\Component\Uuid\Uuid;

/**
 * Mocks the client factory service.
 */
class ClientFactoryMock extends ClientFactory {

  /**
   * Override original, and replace Content Hub client with mock.
   */
  public function registerClient(string $name, string $url, string $api_key, string $secret, string $api_version = 'v2'): ContentHubClient {
    if ($name === 'accountIsNotFeatured') {
      throw new PlatformIncompatibilityException(
        PlatformIncompatibilityException::$incompatiblePlatform
      );
    }

    return ContentHubClientMock::register($this->logger, $this->dispatcher, $name, $url, $api_key, $secret);
  }

  /**
   * {@inheritdoc}
   */
  public function getClient(Settings $settings = NULL) {
    if (isset($this->client)) {
      return $this->client;
    }

    if (!$this->settings
      || !Uuid::isValid($this->settings->getUuid())
      || empty($this->settings->getName())
      || empty($this->settings->getUrl())
      || empty($this->settings->getApiKey())
      || empty($this->settings->getSecretKey())
    ) {
      return FALSE;
    }

    // Override configuration.
    $config = [
      'base_url' => $this->settings->getUrl(),
      'client-user-agent' => $this->getClientUserAgent(),
    ];

    $this->client = new ContentHubClientMock(
      $this->logger,
      $this->settings,
      $this->settings->getMiddleware(),
      $this->dispatcher,
      $config
    );

    return $this->client;
  }

  /**
   * {@inheritDoc}
   */
  public function isConfigurationSet(Settings $settings = NULL): bool {
    return TRUE;
  }

}

==> acquia_contenthub-3.2.1.tar.gz: acquia_contenthub/tests/modules/acquia_contenthub_server_test/src/Client/ClientFactoryMock.php <==
<?php

namespace Drupal\acquia_contenthub_server_test\Client;

use Acquia\ContentHubClient\ContentHubClient;
use Acquia\ContentHubClient\Settings;
use Drupal\acquia_contenthub\Client\ClientFactory;
use Drupal\acquia_contenthub\Exception\PlatformIncompatibilityException;
use Drupal\Component\Uuid\Uuid;

/**
 * Mocks the client factory service.
 */
class ClientFactoryMock extends ClientFactory {

  /**
   * Override original, and replace Content Hub client with mock.
   */
  public function registerClient(string $name, string $url, string $api_key, string $secret, string $api_version = 'v2'): ContentHubClient {
    if ($name === 'accountIsNotFeatured') {
      throw new PlatformIncompatibilityException(
        PlatformIncompatibilityException::$incompatiblePlatform
      );
    }

    return ContentHubClientMock::register($this->logger, $this->dispatcher, $name, $url, $api_key, $secret);
  }

  /**
   * {@inheritdoc}
   */
  public function getClient(Settings $settings = NULL) {
    if (isset($this->client)) {
      return $this->client;
    }
    if ($settings === NULL) {
      $settings = $this->getSettings();
    }
    else {
      $this->settings = $settings;
    }
    if (!$settings
      || !Uuid::isValid($settings->getUuid())
      || empty($settings->getName())
      || empty($settings->getUrl())
      || empty($settings->getApiKey())
      || empty($settings->getSecretKey())
    ) {
      return FALSE;
    }

    // Override configuration.
    $config = [
      'base_url' => $settings->getUrl(),
      'client-user-agent' => $this->getClientUserAgent(),
    ];

    $this->client = new ContentHubClientMock(
      $this->logger,
      $settings,
      $settings->getMiddleware(),
      $this->dispatcher,
      $config
    );

    return $this->client;
  }

  /**
   * {@inheritDoc}
   */
  public function isConfigurationSet(Settings $settings = NULL): bool {
    return TRUE;
  }

}
